@@ -1,6 +1,10 @@
 import uuid
 import json
 from datetime import datetime, timedelta
+
+from djangoldp.permissions import LDPPermissions
+
+from djangoldp.serializers import LDListMixin, LDPSerializer
 from rest_framework.test import APITestCase, APIClient
 from guardian.shortcuts import assign_perm
 
@@ -11,6 +15,9 @@ from djangoldp_circle.tests.models import User
 class PermissionsTestCase(APITestCase):
     def setUp(self):
         self.client = APIClient()
+        LDListMixin.to_representation_cache.reset()
+        LDPSerializer.to_representation_cache.reset()
+        LDPPermissions.invalidate_cache()
 
     def setUpLoggedInUser(self):
         self.user = User(email='test@mactest.co.uk', first_name='Test', last_name='Mactest', username='test',
@@ -18,11 +25,14 @@ class PermissionsTestCase(APITestCase):
         self.user.save()
         self.client.force_authenticate(user=self.user)
 
-    def setUpCircle(self, status_choice='Public', owner=None):
+    def _get_random_circle(self, status_choice='Public', owner=None):
         if owner is None:
             owner = self.user
 
-        self.circle = Circle.objects.create(name='Test', status=status_choice, owner=owner)
+        return Circle.objects.create(name='Test', status=status_choice, owner=owner)
+
+    def setUpCircle(self, status_choice='Public', owner=None):
+        self.circle = self._get_random_circle(status_choice, owner)
 
     def _get_circle_member_request_json(self, user, circle=None):
         res = self._get_request_json(user=user.urlid)
@@ -68,6 +78,13 @@ class PermissionsTestCase(APITestCase):
         return User.objects.create(email='{}@test.co.uk'.format(str(uuid.uuid4())), first_name='Test', last_name='Test',
                                    username=str(uuid.uuid4()))
 
+    # list circles - not logged in
+    def test_list_circles_anonymous_user(self):
+        another_user = self._get_random_user()
+        self.setUpCircle('Public', another_user)
+        response = self.client.get('/circles/')
+        self.assertEqual(response.status_code, 403)
+
     # GET circle - not logged in
     def test_get_circle_anonymous_user(self):
         another_user = self._get_random_user()
@@ -76,6 +93,19 @@ class PermissionsTestCase(APITestCase):
         response = self.client.get('/circles/1/')
         self.assertEqual(response.status_code, 403)
 
+    # list circles - not include private circles
+    def test_list_circles(self):
+        self.setUpLoggedInUser()
+        # a public circle, a private circle I own and a private circle I'm not in
+        another_user = self._get_random_user()
+        public_circle = self._get_random_circle('Public', another_user)
+        my_circle = self._get_random_circle('Private', self.user)
+        private_circle = self._get_random_circle('Private', another_user)
+
+        response = self.client.get('/circles/')
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(len(response.data['ldp:contains']), 2)
+
     # GET circle public
     def test_get_public_circle(self):
         self.setUpLoggedInUser()
